pilas.motores.motor_qt.Grilla

Package pilas :: Package motores :: Module motor_qt :: Class Grilla |
[hide private]
[frames] | no frames]

# Class Grilla

source code

    object --+
             |
        Imagen --+
                 |
                Grilla

Representa una grilla regular, que se utiliza en animaciones.

La grilla regular se tiene que crear indicando la cantidad de filas y columnas. Una vez definida se puede usar como una imagen normal, solo que tiene dos metodos adicionales para ``definir_cuadro`` y ``avanzar`` el cuadro actual.

Instance Methods | [hide private]
__init__(self, ruta, columnas=1, filas=1) x.__init__(...) initializes x; see help(type(x)) for signature | source code
ancho(self) | source code
alto(self) | source code
_dibujar_pixmap(self, painter, x, y) | source code
definir_cuadro(self, cuadro) | source code
avanzar(self) | source code
obtener_cuadro(self) | source code
dibujarse_sobre_una_pizarra(self, pizarra, x, y) | source code
Inherited from `Imagen`: `__str__`, `cargar_jpeg`, `centro`, `dibujar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, ruta, columnas=1, filas=1) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### ancho(self) | source code
Overrides: Imagen.ancho

### alto(self) | source code
Overrides: Imagen.alto

### _dibujar_pixmap(self, painter, x, y) | source code
Overrides: Imagen._dibujar_pixmap

### avanzar(self) | source code
Overrides: Imagen.avanzar